pub struct Owner { /* private fields */ }Expand description
Request descriptor for reservations related to one Gingr owner/customer record.
Implementations
Sourceimpl Owner
impl Owner
Sourcepub const LOCATION_SCOPE_CAVEAT: &'static str = Animal::LOCATION_SCOPE_CAVEAT
pub const LOCATION_SCOPE_CAVEAT: &'static str = Animal::LOCATION_SCOPE_CAVEAT
Notes that Gingr scopes this lookup to the API user’s current location.
Sourcepub fn builder() -> OwnerBuilder
pub fn builder() -> OwnerBuilder
Starts a builder that makes each provider parameter explicit before request capture.